.. _examples:

Examples
========
|

The following section includes example scripts of some common tasks and objectives that the SDK is frequently used for.

These examples are intended solely as a jumping-off point for developers new to the SDK; to provide an idea of how
some common tasks might be written out programmatically using the tools and resources available in the SDK.

Before running an example, your API credentials must be obtained as described in  :ref:`Api Credentials <api-credentials>`.

.. toctree::
   :maxdepth: 3
   :hidden:

   examples/sdk_examples_self_managed_deployment
   examples/sdk_examples_job_pipeline
